@@ -24,8 +24,7 @@ namespace pika::detail {
     using bounds_type = std::vector<std::int64_t>;
 
     ///////////////////////////////////////////////////////////////////////////
-    void parse_mappings(
-        std::string const& spec, mappings_type& mappings, error_code& ec)
+    void parse_mappings(std::string const& spec, mappings_type& mappings, error_code& ec)
     {
         if (spec == "compact")
         {
@@ -45,8 +44,7 @@ namespace pika::detail {
         }
         else
         {
-            PIKA_THROWS_IF(ec, pika::error::bad_parameter,
-                "parse_affinity_options",
+            PIKA_THROWS_IF(ec, pika::error::bad_parameter, "parse_affinity_options",
                 "failed to parse affinity specification: \"{}\"", spec);
         }
 
@@ -75,8 +73,7 @@ namespace pika::detail {
         for (std::int64_t index : b)
         {
             masks.push_back(std::make_tuple(static_cast<std::size_t>(index),
-                t.init_socket_affinity_mask_from_socket(
-                    static_cast<std::size_t>(index))));
+                t.init_socket_affinity_mask_from_socket(static_cast<std::size_t>(index))));
         }
         return masks;
     }
@@ -88,8 +85,7 @@ namespace pika::detail {
         for (std::int64_t index : b)
         {
             masks.push_back(std::make_tuple(static_cast<std::size_t>(index),
-                t.init_numa_node_affinity_mask_from_numa_node(
-                    static_cast<std::size_t>(index))));
+                t.init_numa_node_affinity_mask_from_numa_node(static_cast<std::size_t>(index))));
         }
         return masks;
     }
@@ -110,8 +106,7 @@ namespace pika::detail {
         }
 
         threads::detail::mask_type proc_mask = t.get_cpubind_mask();
-        threads::detail::mask_type pu_mask =
-            t.init_thread_affinity_mask(num_core, num_pu);
+        threads::detail::mask_type pu_mask = t.init_thread_affinity_mask(num_core, num_pu);
 
         return threads::detail::bit_and(proc_mask, pu_mask);
     }
@@ -126,24 +121,21 @@ namespace pika::detail {
 
             if (num_threads > num_pus_proc_mask)
             {
-                PIKA_THROWS_IF(ec, pika::error::bad_parameter,
-                    "check_num_threads",
-                    "specified number of threads ({}) is larger than number "
-                    "of processing units available in process mask ({})",
+                PIKA_THROWS_IF(ec, pika::error::bad_parameter, "check_num_threads",
+                    "specified number of threads ({}) is larger than number of processing units "
+                    "available in process mask ({})",
                     num_threads, num_pus_proc_mask);
             }
         }
         else
         {
-            std::size_t num_threads_available =
-                threads::detail::hardware_concurrency();
+            std::size_t num_threads_available = threads::detail::hardware_concurrency();
 
             if (num_threads > num_threads_available)
             {
-                PIKA_THROWS_IF(ec, pika::error::bad_parameter,
-                    "check_num_threads",
-                    "specified number of threads ({}) is larger than number "
-                    "of available processing units ({})",
+                PIKA_THROWS_IF(ec, pika::error::bad_parameter, "check_num_threads",
+                    "specified number of threads ({}) is larger than number of available "
+                    "processing units ({})",
                     num_threads, num_threads_available);
             }
         }
@@ -152,9 +144,8 @@ namespace pika::detail {
     ///////////////////////////////////////////////////////////////////////////
     // NOLINTBEGIN(bugprone-easily-swappable-parameters)
     void decode_compact_distribution(threads::detail::topology& t,
-        std::vector<threads::detail::mask_type>& affinities,
-        std::size_t used_cores, std::size_t max_cores,
-        std::vector<std::size_t>& num_pus, bool use_process_mask,
+        std::vector<threads::detail::mask_type>& affinities, std::size_t used_cores,
+        std::size_t max_cores, std::vector<std::size_t>& num_pus, bool use_process_mask,
         error_code& ec)
     // NOLINTEND(bugprone-easily-swappable-parameters)
     {
@@ -175,12 +166,10 @@ namespace pika::detail {
         {
             for (std::size_t num_core = 0; num_core < num_cores; ++num_core)
             {
-                std::size_t num_core_pus =
-                    t.get_number_of_core_pus(num_core + used_cores);
+                std::size_t num_core_pus = t.get_number_of_core_pus(num_core + used_cores);
                 for (std::size_t num_pu = 0; num_pu < num_core_pus; ++num_pu)
                 {
-                    if (!pu_in_process_mask(
-                            use_process_mask, t, num_core, num_pu))
+                    if (!pu_in_process_mask(use_process_mask, t, num_core, num_pu))
                     {
                         continue;
                     }
@@ -189,15 +178,13 @@ namespace pika::detail {
                     {
                         PIKA_THROWS_IF(ec, pika::error::bad_parameter,
                             "decode_compact_distribution",
-                            "affinity mask for thread {} has already been set",
-                            num_thread);
+                            "affinity mask for thread {} has already been set", num_thread);
                         return;
                     }
 
-                    num_pus[num_thread] =
-                        t.get_pu_number(num_core + used_cores, num_pu);
-                    affinities[num_thread] = t.init_thread_affinity_mask(
-                        num_core + used_cores, num_pu);
+                    num_pus[num_thread] = t.get_pu_number(num_core + used_cores, num_pu);
+                    affinities[num_thread] =
+                        t.init_thread_affinity_mask(num_core + used_cores, num_pu);
 
                     if (++num_thread == num_threads)
                         return;
@@ -208,9 +195,8 @@ namespace pika::detail {
 
     // NOLINTBEGIN(bugprone-easily-swappable-parameters)
     void decode_scatter_distribution(threads::detail::topology& t,
-        std::vector<threads::detail::mask_type>& affinities,
-        std::size_t used_cores, std::size_t max_cores,
-        std::vector<std::size_t>& num_pus, bool use_process_mask,
+        std::vector<threads::detail::mask_type>& affinities, std::size_t used_cores,
+        std::size_t max_cores, std::vector<std::size_t>& num_pus, bool use_process_mask,
         error_code& ec)
     // NOLINTEND(bugprone-easily-swappable-parameters)
     {
@@ -235,10 +221,8 @@ namespace pika::detail {
             {
                 if (threads::detail::any(affinities[num_thread]))
                 {
-                    PIKA_THROWS_IF(ec, pika::error::bad_parameter,
-                        "decode_scatter_distribution",
-                        "affinity mask for thread {} has already been set",
-                        num_thread);
+                    PIKA_THROWS_IF(ec, pika::error::bad_parameter, "decode_scatter_distribution",
+                        "affinity mask for thread {} has already been set", num_thread);
                     return;
                 }
 
@@ -249,8 +233,7 @@ namespace pika::detail {
                 // Find the next PU on this core which is in the process mask
                 while (pu_index < num_core_pus)
                 {
-                    use_pu = pu_in_process_mask(
-                        use_process_mask, t, num_core, pu_index);
+                    use_pu = pu_in_process_mask(use_process_mask, t, num_core, pu_index);
                     ++pu_index;
 
                     if (use_pu)
@@ -266,10 +249,10 @@ namespace pika::detail {
                     continue;
                 }
 
-                num_pus[num_thread] = t.get_pu_number(
-                    num_core + used_cores, next_pu_index[num_core] - 1);
-                affinities[num_thread] = t.init_thread_affinity_mask(
-                    num_core + used_cores, next_pu_index[num_core] - 1);
+                num_pus[num_thread] =
+                    t.get_pu_number(num_core + used_cores, next_pu_index[num_core] - 1);
+                affinities[num_thread] =
+                    t.init_thread_affinity_mask(num_core + used_cores, next_pu_index[num_core] - 1);
 
                 if (++num_thread == num_threads)
                     return;
@@ -280,9 +263,8 @@ namespace pika::detail {
     ///////////////////////////////////////////////////////////////////////////
     // NOLINTBEGIN(bugprone-easily-swappable-parameters)
     void decode_balanced_distribution(threads::detail::topology& t,
-        std::vector<threads::detail::mask_type>& affinities,
-        std::size_t used_cores, std::size_t max_cores,
-        std::vector<std::size_t>& num_pus, bool use_process_mask,
+        std::vector<threads::detail::mask_type>& affinities, std::size_t used_cores,
+        std::size_t max_cores, std::vector<std::size_t>& num_pus, bool use_process_mask,
         error_code& ec)
     // NOLINTEND(bugprone-easily-swappable-parameters)
     {
@@ -317,8 +299,7 @@ namespace pika::detail {
                 // Find the next PU on this core which is in the process mask
                 while (pu_index < num_core_pus)
                 {
-                    use_pu = pu_in_process_mask(
-                        use_process_mask, t, num_core, pu_index);
+                    use_pu = pu_in_process_mask(use_process_mask, t, num_core, pu_index);
                     ++pu_index;
 
                     if (use_pu)
@@ -347,20 +328,17 @@ namespace pika::detail {
         std::size_t num_thread = 0;
         for (std::size_t num_core = 0; num_core < num_cores; ++num_core)
         {
-            for (std::size_t num_pu = 0; num_pu < num_pus_cores[num_core];
-                 ++num_pu)
+            for (std::size_t num_pu = 0; num_pu < num_pus_cores[num_core]; ++num_pu)
             {
                 if (threads::detail::any(affinities[num_thread]))
                 {
-                    PIKA_THROWS_IF(ec, pika::error::bad_parameter,
-                        "decode_balanced_distribution",
-                        "affinity mask for thread {} has already been set",
-                        num_thread);
+                    PIKA_THROWS_IF(ec, pika::error::bad_parameter, "decode_balanced_distribution",
+                        "affinity mask for thread {} has already been set", num_thread);
                     return;
                 }
 
-                num_pus[num_thread] = t.get_pu_number(
-                    num_core + used_cores, pu_indexes[num_core][num_pu]);
+                num_pus[num_thread] =
+                    t.get_pu_number(num_core + used_cores, pu_indexes[num_core][num_pu]);
                 affinities[num_thread] = t.init_thread_affinity_mask(
                     num_core + used_cores, pu_indexes[num_core][num_pu]);
                 ++num_thread;
@@ -371,9 +349,8 @@ namespace pika::detail {
     ///////////////////////////////////////////////////////////////////////////
     // NOLINTBEGIN(bugprone-easily-swappable-parameters)
     void decode_numabalanced_distribution(threads::detail::topology& t,
-        std::vector<threads::detail::mask_type>& affinities,
-        std::size_t used_cores, std::size_t max_cores,
-        std::vector<std::size_t>& num_pus, bool use_process_mask,
+        std::vector<threads::detail::mask_type>& affinities, std::size_t used_cores,
+        std::size_t max_cores, std::vector<std::size_t>& num_pus, bool use_process_mask,
         error_code& ec)
     // NOLINTEND(bugprone-easily-swappable-parameters)
     {
@@ -390,8 +367,7 @@ namespace pika::detail {
         num_pus.resize(num_threads);
 
         // numa nodes
-        std::size_t num_numas =
-            (std::max)(std::size_t(1), t.get_number_of_numa_nodes());
+        std::size_t num_numas = (std::max)(std::size_t(1), t.get_number_of_numa_nodes());
         std::vector<std::size_t> num_cores_numa(num_numas, 0);
         std::vector<std::size_t> num_pus_numa(num_numas, 0);
         std::vector<std::size_t> num_threads_numa(num_numas, 0);
@@ -404,15 +380,12 @@ namespace pika::detail {
         std::size_t pus_t = 0;
         for (std::size_t n = 0; n < num_numas; ++n)
         {
-            for (std::size_t num_core = 0; num_core < num_cores_numa[n];
-                 ++num_core)
+            for (std::size_t num_core = 0; num_core < num_cores_numa[n]; ++num_core)
             {
-                std::size_t num_pus =
-                    t.get_number_of_core_pus(num_core + core_offset);
+                std::size_t num_pus = t.get_number_of_core_pus(num_core + core_offset);
                 for (std::size_t num_pu = 0; num_pu < num_pus; ++num_pu)
                 {
-                    if (pu_in_process_mask(use_process_mask, t,
-                            num_core + core_offset, num_pu))
+                    if (pu_in_process_mask(use_process_mask, t, num_core + core_offset, num_pu))
                     {
                         ++num_pus_numa[n];
                     }
@@ -427,9 +400,8 @@ namespace pika::detail {
         std::size_t pus_t2 = 0;
         for (std::size_t n = 0; n < num_numas; ++n)
         {
-            std::size_t temp = static_cast<std::size_t>(
-                std::round(static_cast<double>(num_threads * num_pus_numa[n]) /
-                    static_cast<double>(pus_t)));
+            std::size_t temp = static_cast<std::size_t>(std::round(
+                static_cast<double>(num_threads * num_pus_numa[n]) / static_cast<double>(pus_t)));
 
             // due to rounding up, we might have too many threads
             if ((pus_t2 + temp) > num_threads)
@@ -452,23 +424,20 @@ namespace pika::detail {
             std::vector<std::vector<std::size_t>> pu_indexes(num_cores_numa[n]);
 
             // iterate once and count pus/core
-            for (std::size_t num_thread_numa = 0;
-                 num_thread_numa < num_threads_numa[n];
+            for (std::size_t num_thread_numa = 0; num_thread_numa < num_threads_numa[n];
                 /**/)
             {
-                for (std::size_t num_core = 0; num_core < num_cores_numa[n];
-                     ++num_core)
+                for (std::size_t num_core = 0; num_core < num_cores_numa[n]; ++num_core)
                 {
-                    std::size_t num_core_pus =
-                        t.get_number_of_core_pus(num_core);
+                    std::size_t num_core_pus = t.get_number_of_core_pus(num_core);
                     std::size_t pu_index = next_pu_index[num_core];
                     bool use_pu = false;
 
                     // Find the next PU on this core which is in the process mask
                     while (pu_index < num_core_pus)
                     {
-                        use_pu = pu_in_process_mask(use_process_mask, t,
-                            num_core + core_offset, pu_index);
+                        use_pu = pu_in_process_mask(
+                            use_process_mask, t, num_core + core_offset, pu_index);
                         ++pu_index;
 
                         if (use_pu)
@@ -494,25 +463,21 @@ namespace pika::detail {
 
             // Iterate over the cores and assigned pus per core. this additional
             // loop is needed so that we have consecutive worker thread numbers
-            for (std::size_t num_core = 0; num_core < num_cores_numa[n];
-                 ++num_core)
+            for (std::size_t num_core = 0; num_core < num_cores_numa[n]; ++num_core)
             {
-                for (std::size_t num_pu = 0; num_pu < num_pus_cores[num_core];
-                     ++num_pu)
+                for (std::size_t num_pu = 0; num_pu < num_pus_cores[num_core]; ++num_pu)
                 {
                     if (threads::detail::any(affinities[num_thread]))
                     {
                         PIKA_THROWS_IF(ec, pika::error::bad_parameter,
                             "decode_numabalanced_distribution",
-                            "affinity mask for thread {} has already been set",
-                            num_thread);
+                            "affinity mask for thread {} has already been set", num_thread);
                         return;
                     }
-                    num_pus[num_thread] = t.get_pu_number(
-                        num_core + used_cores, pu_indexes[num_core][num_pu]);
+                    num_pus[num_thread] =
+                        t.get_pu_number(num_core + used_cores, pu_indexes[num_core][num_pu]);
                     affinities[num_thread] = t.init_thread_affinity_mask(
-                        num_core + used_cores + core_offset,
-                        pu_indexes[num_core][num_pu]);
+                        num_core + used_cores + core_offset, pu_indexes[num_core][num_pu]);
                     ++num_thread;
                 }
             }
@@ -523,33 +488,32 @@ namespace pika::detail {
     ///////////////////////////////////////////////////////////////////////////
     // NOLINTBEGIN(bugprone-easily-swappable-parameters)
     void decode_distribution(distribution_type d, threads::detail::topology& t,
-        std::vector<threads::detail::mask_type>& affinities,
-        std::size_t used_cores, std::size_t max_cores, std::size_t num_threads,
-        std::vector<std::size_t>& num_pus, bool use_process_mask,
-        error_code& ec)
+        std::vector<threads::detail::mask_type>& affinities, std::size_t used_cores,
+        std::size_t max_cores, std::size_t num_threads, std::vector<std::size_t>& num_pus,
+        bool use_process_mask, error_code& ec)
     // NOLINTEND(bugprone-easily-swappable-parameters)
     {
         affinities.resize(num_threads);
         switch (d)
         {
         case compact:
-            decode_compact_distribution(t, affinities, used_cores, max_cores,
-                num_pus, use_process_mask, ec);
+            decode_compact_distribution(
+                t, affinities, used_cores, max_cores, num_pus, use_process_mask, ec);
             break;
 
         case scatter:
-            decode_scatter_distribution(t, affinities, used_cores, max_cores,
-                num_pus, use_process_mask, ec);
+            decode_scatter_distribution(
+                t, affinities, used_cores, max_cores, num_pus, use_process_mask, ec);
             break;
 
         case balanced:
-            decode_balanced_distribution(t, affinities, used_cores, max_cores,
-                num_pus, use_process_mask, ec);
+            decode_balanced_distribution(
+                t, affinities, used_cores, max_cores, num_pus, use_process_mask, ec);
             break;
 
         case numa_balanced:
-            decode_numabalanced_distribution(t, affinities, used_cores,
-                max_cores, num_pus, use_process_mask, ec);
+            decode_numabalanced_distribution(
+                t, affinities, used_cores, max_cores, num_pus, use_process_mask, ec);
             break;
 
         default:
@@ -559,10 +523,9 @@ namespace pika::detail {
 
     ///////////////////////////////////////////////////////////////////////////
     void parse_affinity_options(std::string const& spec,
-        std::vector<threads::detail::mask_type>& affinities,
-        std::size_t used_cores, std::size_t max_cores, std::size_t num_threads,
-        std::vector<std::size_t>& num_pus, bool use_process_mask,
-        error_code& ec)
+        std::vector<threads::detail::mask_type>& affinities, std::size_t used_cores,
+        std::size_t max_cores, std::size_t num_threads, std::vector<std::size_t>& num_pus,
+        bool use_process_mask, error_code& ec)
     {
         mappings_type mappings;
         parse_mappings(spec, mappings, ec);
@@ -573,8 +536,8 @@ namespace pika::detail {
         // been initialized yet
         threads::detail::topology& t = threads::detail::create_topology();
 
-        decode_distribution(mappings, t, affinities, used_cores, max_cores,
-            num_threads, num_pus, use_process_mask, ec);
+        decode_distribution(mappings, t, affinities, used_cores, max_cores, num_threads, num_pus,
+            use_process_mask, ec);
         if (ec)
             return;
     }
