@@ -25,8 +25,8 @@ namespace pika::detail {
         }
     }
 
-    void handle_assert(source_location const& loc, const char* expr,
-        std::string const& msg) noexcept
+    void handle_assert(
+        source_location const& loc, const char* expr, std::string const& msg) noexcept
     {
         if (get_handler() == nullptr)
         {
