@@ -74,8 +74,7 @@ namespace pika::detail {
     }
 
     ///////////////////////////////////////////////////////////////////////
-    inline void encode(
-        std::string& str, char s, char const* r, std::size_t inc = 1ull)
+    inline void encode(std::string& str, char s, char const* r, std::size_t inc = 1ull)
     {
         std::string::size_type pos = 0;
         while ((pos = str.find_first_of(s, pos)) != std::string::npos)
@@ -143,8 +142,7 @@ namespace pika::detail {
         {
             std::string affinity_desc;
 
-            std::vector<std::string> bind_affinity =
-                vm["pika:bind"].as<std::vector<std::string>>();
+            std::vector<std::string> bind_affinity = vm["pika:bind"].as<std::vector<std::string>>();
             for (std::string const& s : bind_affinity)
             {
                 if (!affinity_desc.empty())
@@ -186,15 +184,12 @@ namespace pika::detail {
     {
         if (vm.count("pika:numa-sensitive") != 0)
         {
-            std::size_t numa_sensitive =
-                vm["pika:numa-sensitive"].as<std::size_t>();
+            std::size_t numa_sensitive = vm["pika:numa-sensitive"].as<std::size_t>();
             if (numa_sensitive > 2)
             {
                 throw pika::detail::command_line_error(
-                    "Invalid argument "
-                    "value for --pika:numa-sensitive. Allowed values "
-                    "are "
-                    "0, 1, or 2");
+                    "Invalid argument value for --pika:numa-sensitive. Allowed values are 0, 1, or "
+                    "2");
             }
             return numa_sensitive;
         }
@@ -246,22 +241,18 @@ namespace pika::detail {
 
     ///////////////////////////////////////////////////////////////////////
     std::size_t handle_num_threads(detail::manage_config& cfgmap,
-        pika::util::runtime_configuration const& rtcfg,
-        pika::program_options::variables_map& vm, bool use_process_mask)
+        pika::util::runtime_configuration const& rtcfg, pika::program_options::variables_map& vm,
+        bool use_process_mask)
     {
         // If using the process mask we override "cores" and "all" options but
         // keep explicit numeric values.
-        const std::size_t init_threads =
-            get_number_of_default_threads(use_process_mask);
-        const std::size_t init_cores =
-            get_number_of_default_cores(use_process_mask);
+        const std::size_t init_threads = get_number_of_default_threads(use_process_mask);
+        const std::size_t init_cores = get_number_of_default_cores(use_process_mask);
 
         std::size_t default_threads = init_threads;
 
-        std::string threads_str =
-            cfgmap.get_value<std::string>("pika.os_threads",
-                rtcfg.get_entry(
-                    "pika.os_threads", std::to_string(default_threads)));
+        std::string threads_str = cfgmap.get_value<std::string>(
+            "pika.os_threads", rtcfg.get_entry("pika.os_threads", std::to_string(default_threads)));
 
         if ("cores" == threads_str)
         {
@@ -273,11 +264,10 @@ namespace pika::detail {
         }
         else
         {
-            default_threads = pika::util::from_string<std::size_t>(threads_str);
+            default_threads = pika::detail::from_string<std::size_t>(threads_str);
         }
 
-        std::size_t threads =
-            cfgmap.get_value<std::size_t>("pika.os_threads", default_threads);
+        std::size_t threads = cfgmap.get_value<std::size_t>("pika.os_threads", default_threads);
 
         if (vm.count("pika:threads"))
         {
@@ -292,7 +282,7 @@ namespace pika::detail {
             }
             else
             {
-                threads = pika::util::from_string<std::size_t>(threads_str);
+                threads = pika::detail::from_string<std::size_t>(threads_str);
             }
 
             if (threads == 0)
@@ -321,23 +311,16 @@ namespace pika::detail {
         if (min_os_threads == 0)
         {
             throw pika::detail::command_line_error(
-                "Number of pika.force_min_os_threads must be greater "
-                "than "
-                "0");
+                "Number of pika.force_min_os_threads must be greater than 0");
         }
 
 #if defined(PIKA_HAVE_MAX_CPU_COUNT)
         if (min_os_threads > PIKA_HAVE_MAX_CPU_COUNT)
         {
-            throw pika::detail::command_line_error(
-                "Requested more than " PIKA_PP_STRINGIZE(
-                    PIKA_HAVE_MAX_CPU_COUNT) " pika.force_min_os_threads "
-                                             "to use for this "
-                                             "application, "
-                                             "use the option "
-                                             "-DPIKA_WITH_MAX_CPU_COUNT=<"
-                                             "N> "
-                                             "when configuring pika.");
+            throw pika::detail::command_line_error("Requested more than " PIKA_PP_STRINGIZE(
+                PIKA_HAVE_MAX_CPU_COUNT) " pika.force_min_os_threads to use for this application, "
+                                         "use the option -DPIKA_WITH_MAX_CPU_COUNT=<N> when "
+                                         "configuring pika.");
         }
 #endif
 
@@ -347,8 +330,7 @@ namespace pika::detail {
     }
 
     std::size_t handle_num_cores(detail::manage_config& cfgmap,
-        pika::program_options::variables_map& vm, std::size_t num_threads,
-        bool use_process_mask)
+        pika::program_options::variables_map& vm, std::size_t num_threads, bool use_process_mask)
     {
         std::string cores_str = cfgmap.get_value<std::string>("pika.cores", "");
         if ("all" == cores_str)
@@ -357,8 +339,7 @@ namespace pika::detail {
                 std::to_string(get_number_of_default_cores(use_process_mask));
         }
 
-        std::size_t num_cores =
-            cfgmap.get_value<std::size_t>("pika.cores", num_threads);
+        std::size_t num_cores = cfgmap.get_value<std::size_t>("pika.cores", num_threads);
         if (vm.count("pika:cores"))
         {
             cores_str = vm["pika:cores"].as<std::string>();
@@ -368,7 +349,7 @@ namespace pika::detail {
             }
             else
             {
-                num_cores = pika::util::from_string<std::size_t>(cores_str);
+                num_cores = pika::detail::from_string<std::size_t>(cores_str);
             }
         }
 
@@ -386,10 +367,8 @@ namespace pika::detail {
                 0 != std::string("machine").find(affinity_domain_))
             {
                 throw pika::detail::command_line_error(
-                    "Invalid command line option "
-                    "--pika:affinity, value must be one of: pu, core, "
-                    "numa, "
-                    "or machine.");
+                    "Invalid command line option --pika:affinity, value must be one of: pu, core, "
+                    "numa, or machine.");
             }
         }
     }
@@ -401,14 +380,12 @@ namespace pika::detail {
             return;
         }
 
-        if (!(pu_offset_ == std::size_t(-1) || pu_offset_ == std::size_t(0)) ||
-            pu_step_ != 1 || affinity_domain_ != "pu")
+        if (!(pu_offset_ == std::size_t(-1) || pu_offset_ == std::size_t(0)) || pu_step_ != 1 ||
+            affinity_domain_ != "pu")
         {
             throw pika::detail::command_line_error(
-                "Command line option --pika:bind "
-                "should not be used with --pika:pu-step, "
-                "--pika:pu-offset, "
-                "or --pika:affinity.");
+                "Command line option --pika:bind should not be used with --pika:pu-step, "
+                "--pika:pu-offset, or --pika:affinity.");
         }
     }
 
@@ -418,37 +395,31 @@ namespace pika::detail {
             pu_offset_ >= pika::threads::detail::hardware_concurrency())
         {
             throw pika::detail::command_line_error(
-                "Invalid command line option "
-                "--pika:pu-offset, value must be smaller than number of "
-                "available processing units.");
+                "Invalid command line option --pika:pu-offset, value must be smaller than number "
+                "of available processing units.");
         }
     }
 
     void command_line_handling::check_pu_step() const
     {
         if (pika::threads::detail::hardware_concurrency() > 1 &&
-            (pu_step_ == 0 ||
-                pu_step_ >= pika::threads::detail::hardware_concurrency()))
+            (pu_step_ == 0 || pu_step_ >= pika::threads::detail::hardware_concurrency()))
         {
             throw pika::detail::command_line_error(
-                "Invalid command line option "
-                "--pika:pu-step, value must be non-zero and smaller "
-                "than "
-                "number of available processing units.");
+                "Invalid command line option --pika:pu-step, value must be non-zero and smaller "
+                "than number of available processing units.");
         }
     }
 
     ///////////////////////////////////////////////////////////////////////////
     bool command_line_handling::handle_arguments(detail::manage_config& cfgmap,
-        pika::program_options::variables_map& vm,
-        std::vector<std::string>& ini_config)
+        pika::program_options::variables_map& vm, std::vector<std::string>& ini_config)
     {
         bool debug_clp = vm.count("pika:debug-clp");
 
         if (vm.count("pika:ini"))
         {
-            std::vector<std::string> cfg =
-                vm["pika:ini"].as<std::vector<std::string>>();
+            std::vector<std::string> cfg = vm["pika:ini"].as<std::vector<std::string>>();
             std::copy(cfg.begin(), cfg.end(), std::back_inserter(ini_config));
             cfgmap.add(cfg);
         }
@@ -461,8 +432,7 @@ namespace pika::detail {
                 (vm.count("pika:ignore-process-mask") > 0));
 #endif
 
-        ini_config.emplace_back(
-            "pika.ignore_process_mask!=" + std::to_string(!use_process_mask_));
+        ini_config.emplace_back("pika.ignore_process_mask!=" + std::to_string(!use_process_mask_));
 
         // handle setting related to schedulers
         queuing_ = detail::handle_queuing(cfgmap, vm, "local-priority-fifo");
@@ -479,10 +449,8 @@ namespace pika::detail {
 #if defined(__APPLE__)
             if (affinity_bind_ != "none")
             {
-                std::cerr << "Warning: thread binding set to \""
-                          << affinity_bind_
-                          << "\" but thread binding is not supported on macOS. "
-                             "Ignoring option."
+                std::cerr << "Warning: thread binding set to \"" << affinity_bind_
+                          << "\" but thread binding is not supported on macOS. Ignoring option."
                           << std::endl;
             }
             affinity_bind_ = "";
@@ -496,8 +464,7 @@ namespace pika::detail {
         if (pu_step_ != 1)
         {
             std::cerr << "Warning: PU step set to \"" << pu_step_
-                      << "\" but thread binding is not supported on macOS. "
-                         "Ignoring option."
+                      << "\" but thread binding is not supported on macOS. Ignoring option."
                       << std::endl;
             pu_step_ = 1;
         }
@@ -513,14 +480,12 @@ namespace pika::detail {
         {
 #if defined(__APPLE__)
             std::cerr << "Warning: PU offset set to \"" << pu_offset_
-                      << "\" but thread binding is not supported on macOS. "
-                         "Ignoring option."
+                      << "\" but thread binding is not supported on macOS. Ignoring option."
                       << std::endl;
             pu_offset_ = std::size_t(-1);
             ini_config.emplace_back("pika.pu_offset=0");
 #else
-            ini_config.emplace_back(
-                "pika.pu_offset=" + std::to_string(pu_offset_));
+            ini_config.emplace_back("pika.pu_offset=" + std::to_string(pu_offset_));
 #endif
         }
         else
@@ -530,15 +495,12 @@ namespace pika::detail {
 
         check_pu_offset();
 
-        numa_sensitive_ = detail::handle_numa_sensitive(
-            cfgmap, vm, affinity_bind_.empty() ? 0 : 1);
-        ini_config.emplace_back(
-            "pika.numa_sensitive=" + std::to_string(numa_sensitive_));
+        numa_sensitive_ = detail::handle_numa_sensitive(cfgmap, vm, affinity_bind_.empty() ? 0 : 1);
+        ini_config.emplace_back("pika.numa_sensitive=" + std::to_string(numa_sensitive_));
 
         // default affinity mode is now 'balanced' (only if no pu-step or
         // pu-offset is given)
-        if (pu_step_ == 1 && pu_offset_ == std::size_t(-1) &&
-            affinity_bind_.empty())
+        if (pu_step_ == 1 && pu_offset_ == std::size_t(-1) && affinity_bind_.empty())
         {
 #if defined(__APPLE__)
             affinity_bind_ = "none";
@@ -551,14 +513,11 @@ namespace pika::detail {
         check_affinity_description();
 
         // handle number of cores and threads
-        num_threads_ =
-            detail::handle_num_threads(cfgmap, rtcfg_, vm, use_process_mask_);
-        num_cores_ = detail::handle_num_cores(
-            cfgmap, vm, num_threads_, use_process_mask_);
+        num_threads_ = detail::handle_num_threads(cfgmap, rtcfg_, vm, use_process_mask_);
+        num_cores_ = detail::handle_num_cores(cfgmap, vm, num_threads_, use_process_mask_);
 
         // Set number of cores and OS threads in configuration.
-        ini_config.emplace_back(
-            "pika.os_threads=" + std::to_string(num_threads_));
+        ini_config.emplace_back("pika.os_threads=" + std::to_string(num_threads_));
         ini_config.emplace_back("pika.cores=" + std::to_string(num_cores_));
 
         if (vm_.count("pika:high-priority-threads"))
@@ -569,20 +528,16 @@ namespace pika::detail {
                 num_high_priority_queues > num_threads_)
             {
                 throw pika::detail::command_line_error(
-                    "Invalid command line option: "
-                    "number of high priority threads ("
-                    "--pika:high-priority-threads), should not be "
-                    "larger "
-                    "than number of threads (--pika:threads)");
+                    "Invalid command line option: number of high priority threads "
+                    "(--pika:high-priority-threads), should not be larger than number of threads "
+                    "(--pika:threads)");
             }
 
             if (!(queuing_ == "local-priority" || queuing_ == "abp-priority"))
             {
                 throw pika::detail::command_line_error(
-                    "Invalid command line option "
-                    "--pika:high-priority-threads, "
-                    "valid for --pika:queuing=local-priority and "
-                    "--pika:queuing=abp-priority only");
+                    "Invalid command line option --pika:high-priority-threads, valid for "
+                    "--pika:queuing=local-priority and --pika:queuing=abp-priority only");
             }
 
             ini_config.emplace_back("pika.thread_queue.high_priority_queues!=" +
@@ -607,18 +562,15 @@ namespace pika::detail {
 
     ///////////////////////////////////////////////////////////////////////////
     void command_line_handling::enable_logging_settings(
-        pika::program_options::variables_map& vm,
-        std::vector<std::string>& ini_config)
+        pika::program_options::variables_map& vm, std::vector<std::string>& ini_config)
     {
 #if defined(PIKA_HAVE_LOGGING)
         if (vm.count("pika:debug-pika-log"))
         {
             ini_config.emplace_back("pika.logging.console.destination=" +
-                detail::convert_to_log_file(
-                    vm["pika:debug-pika-log"].as<std::string>()));
+                detail::convert_to_log_file(vm["pika:debug-pika-log"].as<std::string>()));
             ini_config.emplace_back("pika.logging.destination=" +
-                detail::convert_to_log_file(
-                    vm["pika:debug-pika-log"].as<std::string>()));
+                detail::convert_to_log_file(vm["pika:debug-pika-log"].as<std::string>()));
             ini_config.emplace_back("pika.logging.console.level=5");
             ini_config.emplace_back("pika.logging.level=5");
         }
@@ -626,30 +578,25 @@ namespace pika::detail {
         if (vm.count("pika:debug-timing-log"))
         {
             ini_config.emplace_back("pika.logging.console.timing.destination=" +
-                detail::convert_to_log_file(
-                    vm["pika:debug-timing-log"].as<std::string>()));
+                detail::convert_to_log_file(vm["pika:debug-timing-log"].as<std::string>()));
             ini_config.emplace_back("pika.logging.timing.destination=" +
-                detail::convert_to_log_file(
-                    vm["pika:debug-timing-log"].as<std::string>()));
+                detail::convert_to_log_file(vm["pika:debug-timing-log"].as<std::string>()));
             ini_config.emplace_back("pika.logging.console.timing.level=1");
             ini_config.emplace_back("pika.logging.timing.level=1");
         }
 
         if (vm.count("pika:debug-app-log"))
         {
-            ini_config.emplace_back(
-                "pika.logging.console.application.destination=" +
-                detail::convert_to_log_file(
-                    vm["pika:debug-app-log"].as<std::string>()));
+            ini_config.emplace_back("pika.logging.console.application.destination=" +
+                detail::convert_to_log_file(vm["pika:debug-app-log"].as<std::string>()));
             ini_config.emplace_back("pika.logging.application.destination=" +
-                detail::convert_to_log_file(
-                    vm["pika:debug-app-log"].as<std::string>()));
+                detail::convert_to_log_file(vm["pika:debug-app-log"].as<std::string>()));
             ini_config.emplace_back("pika.logging.console.application.level=5");
             ini_config.emplace_back("pika.logging.application.level=5");
         }
 #else
-        if (vm.count("pika:debug-pika-log") ||
-            vm.count("pika:debug-timing-log") || vm.count("pika:debug-app-log"))
+        if (vm.count("pika:debug-pika-log") || vm.count("pika:debug-timing-log") ||
+            vm.count("pika:debug-app-log"))
         {
             // clang-format off
             throw pika::detail::command_line_error(
@@ -664,8 +611,7 @@ namespace pika::detail {
     }
 
     ///////////////////////////////////////////////////////////////////////////
-    void command_line_handling::store_command_line(
-        int argc, const char* const* argv)
+    void command_line_handling::store_command_line(int argc, const char* const* argv)
     {
         // Collect the command line for diagnostic purposes.
         std::string command;
@@ -700,8 +646,7 @@ namespace pika::detail {
 
     ///////////////////////////////////////////////////////////////////////////
     void command_line_handling::store_unregistered_options(
-        std::string const& cmd_name,
-        std::vector<std::string> const& unregistered_options)
+        std::string const& cmd_name, std::vector<std::string> const& unregistered_options)
     {
         std::string unregistered_options_cmd_line;
 
@@ -710,20 +655,16 @@ namespace pika::detail {
             using iterator_type = std::vector<std::string>::const_iterator;
 
             iterator_type end = unregistered_options.end();
-            for (iterator_type it = unregistered_options.begin(); it != end;
-                 ++it)
-                unregistered_options_cmd_line +=
-                    " " + detail::encode_and_enquote(*it);
+            for (iterator_type it = unregistered_options.begin(); it != end; ++it)
+                unregistered_options_cmd_line += " " + detail::encode_and_enquote(*it);
 
             ini_config_.emplace_back("pika.unknown_cmd_line!=" +
-                detail::encode_and_enquote(cmd_name) +
-                unregistered_options_cmd_line);
+                detail::encode_and_enquote(cmd_name) + unregistered_options_cmd_line);
         }
 
         ini_config_.emplace_back("pika.program_name!=" + cmd_name);
-        ini_config_.emplace_back("pika.reconstructed_cmd_line!=" +
-            encode_and_enquote(cmd_name) + " " + reconstruct_command_line(vm_) +
-            " " + unregistered_options_cmd_line);
+        ini_config_.emplace_back("pika.reconstructed_cmd_line!=" + encode_and_enquote(cmd_name) +
+            " " + reconstruct_command_line(vm_) + " " + unregistered_options_cmd_line);
     }
 
     ///////////////////////////////////////////////////////////////////////////
@@ -744,8 +685,8 @@ namespace pika::detail {
         if (vm_.count("pika:attach-debugger"))
         {
             std::string option = vm_["pika:attach-debugger"].as<std::string>();
-            if (option != "off" && option != "startup" &&
-                option != "exception" && option != "test-failure")
+            if (option != "off" && option != "startup" && option != "exception" &&
+                option != "test-failure")
             {
                 // clang-format off
                 std::cerr <<
@@ -812,8 +753,7 @@ namespace pika::detail {
     }
 
     ///////////////////////////////////////////////////////////////////////////
-    std::vector<std::string> prepend_options(
-        std::vector<std::string>&& args, std::string&& options)
+    std::vector<std::string> prepend_options(std::vector<std::string>&& args, std::string&& options)
     {
         if (options.empty())
         {
@@ -830,8 +770,7 @@ namespace pika::detail {
     }
 
     ///////////////////////////////////////////////////////////////////////////
-    int command_line_handling::call(
-        pika::program_options::options_description const& desc_cmdline,
+    int command_line_handling::call(pika::program_options::options_description const& desc_cmdline,
         int argc, const char* const* argv)
     {
         // set the flag signaling that command line parsing has been done
@@ -847,8 +786,7 @@ namespace pika::detail {
             rtcfg_.parse("<user supplied config>", e, true, false);
 
         // support re-throwing command line exceptions for testing purposes
-        commandline_error_mode error_mode =
-            commandline_error_mode::allow_unregistered;
+        commandline_error_mode error_mode = commandline_error_mode::allow_unregistered;
         if (cfgmap.get_value("pika.commandline.rethrow_errors", 0) != 0)
         {
             error_mode |= commandline_error_mode::rethrow_on_error;
@@ -856,11 +794,9 @@ namespace pika::detail {
 
         // The cfg registry may hold command line options to prepend to the
         // real command line.
-        std::string prepend_command_line =
-            rtcfg_.get_entry("pika.commandline.prepend_options");
+        std::string prepend_command_line = rtcfg_.get_entry("pika.commandline.prepend_options");
 
-        args =
-            prepend_options(PIKA_MOVE(args), PIKA_MOVE(prepend_command_line));
+        args = prepend_options(PIKA_MOVE(args), PIKA_MOVE(prepend_command_line));
 
         // Initial analysis of the command line options. This is
         // preliminary as it will not take into account any aliases as
@@ -871,8 +807,7 @@ namespace pika::detail {
             // creating a separate instance just for the preliminary
             // command line handling.
             pika::program_options::variables_map prevm;
-            if (!parse_commandline(
-                    rtcfg_, desc_cmdline, argv[0], args, prevm, error_mode))
+            if (!parse_commandline(rtcfg_, desc_cmdline, argv[0], args, prevm, error_mode))
             {
                 return -1;
             }
@@ -900,15 +835,14 @@ namespace pika::detail {
             }
 
             // append ini options from command line
-            std::copy(ini_config_.begin(), ini_config_.end(),
-                std::back_inserter(cfg));
+            std::copy(ini_config_.begin(), ini_config_.end(), std::back_inserter(cfg));
 
             // enable logging if invoked requested from command line
             std::vector<std::string> ini_config_logging;
             enable_logging_settings(prevm, ini_config_logging);
 
-            std::copy(ini_config_logging.begin(), ini_config_logging.end(),
-                std::back_inserter(cfg));
+            std::copy(
+                ini_config_logging.begin(), ini_config_logging.end(), std::back_inserter(cfg));
 
             rtcfg_.reconfigure(cfg);
         }
@@ -922,8 +856,8 @@ namespace pika::detail {
         std::vector<std::string> unregistered_options;
 
         if (!parse_commandline(rtcfg_, desc_cmdline, argv[0], args, vm_,
-                error_mode | commandline_error_mode::report_missing_config_file,
-                &help, &unregistered_options))
+                error_mode | commandline_error_mode::report_missing_config_file, &help,
+                &unregistered_options))
         {
             return -1;
         }
@@ -981,31 +915,25 @@ namespace pika::detail {
         {
             bool const command_line_arguments_given =
                 vm_.count("pika:threads") != 0 || vm_.count("pika:cores") != 0;
-            if (num_threads_ == 1 &&
-                get_number_of_default_threads(false) != 1 &&
+            if (num_threads_ == 1 && get_number_of_default_threads(false) != 1 &&
                 !command_line_arguments_given)
             {
                 std::cerr
-                    << "The pika runtime will be started with only one worker "
-                       "thread because the process mask has restricted the "
-                       "available resources to only one thread. If this is "
-                       "unintentional make sure the process mask contains the "
-                       "resources you need or use --pika:ignore-process-mask "
-                       "to use all resources. Use --pika:print-bind to print "
-                       "the thread bindings used by pika.\n";
+                    << "The pika runtime will be started with only one worker thread because the "
+                       "process mask has restricted the available resources to only one thread. If "
+                       "this is unintentional make sure the process mask contains the resources "
+                       "you need or use --pika:ignore-process-mask to use all resources. Use "
+                       "--pika:print-bind to print the thread bindings used by pika.\n";
             }
-            else if (num_cores_ == 1 &&
-                get_number_of_default_cores(false) != 1 &&
+            else if (num_cores_ == 1 && get_number_of_default_cores(false) != 1 &&
                 !command_line_arguments_given)
             {
                 fmt::print(std::cerr,
-                    "The pika runtime will be started on only one core with {} "
-                    "worker threads because the process mask has restricted "
-                    "the available resources to only one core. If this is "
-                    "unintentional make sure the process mask contains the "
-                    "resources you need or use --pika:ignore-process-mask to "
-                    "use all resources. Use --pika:print-bind to print the "
-                    "thread bindings used by pika.\n",
+                    "The pika runtime will be started on only one core with {} worker threads "
+                    "because the process mask has restricted the available resources to only one "
+                    "core. If this is unintentional make sure the process mask contains the "
+                    "resources you need or use --pika:ignore-process-mask to use all resources. "
+                    "Use --pika:print-bind to print the thread bindings used by pika.\n",
                     num_threads_);
             }
         }
