@@ -8,8 +8,8 @@
 
 #include <pika/config.hpp>
 
-#if defined(PIKA_HAVE_P2300_REFERENCE_IMPLEMENTATION)
-#include <pika/execution_base/p2300_forward.hpp>
+#if defined(PIKA_HAVE_STDEXEC)
+# include <pika/execution_base/stdexec_forward.hpp>
 #endif
 
 #include <pika/allocator_support/allocator_deleter.hpp>
@@ -20,7 +20,6 @@
 #include <pika/execution/algorithms/detail/partial_algorithm.hpp>
 #include <pika/execution_base/operation_state.hpp>
 #include <pika/execution_base/sender.hpp>
-#include <pika/functional/invoke_result.hpp>
 #include <pika/futures/detail/future_data.hpp>
 #include <pika/futures/promise.hpp>
 #include <pika/memory/intrusive_ptr.hpp>
@@ -31,6 +30,7 @@
 #include <exception>
 #include <memory>
 #include <optional>
+#include <type_traits>
 #include <utility>
 
 namespace pika::make_future_detail {
@@ -43,14 +43,11 @@ namespace pika::make_future_detail {
         virtual void reset_operation_state() = 0;
 
         using init_no_addref =
-            typename pika::lcos::detail::future_data_allocator<T,
-                Allocator>::init_no_addref;
+            typename pika::lcos::detail::future_data_allocator<T, Allocator>::init_no_addref;
 
         template <typename Allocator_>
-        resettable_operation_state_future_data(
-            init_no_addref no_addref, Allocator_ const& alloc)
-          : pika::lcos::detail::future_data_allocator<T, Allocator>(
-                no_addref, alloc)
+        resettable_operation_state_future_data(init_no_addref no_addref, Allocator_ const& alloc)
+          : pika::lcos::detail::future_data_allocator<T, Allocator>(no_addref, alloc)
         {
         }
     };
@@ -58,12 +55,12 @@ namespace pika::make_future_detail {
     template <typename T, typename Allocator>
     struct make_future_receiver
     {
-        pika::intrusive_ptr<
-            resettable_operation_state_future_data<T, Allocator>>
-            data;
+        using is_receiver = void;
 
-        friend void tag_invoke(pika::execution::experimental::set_error_t,
-            make_future_receiver&& r, std::exception_ptr ep) noexcept
+        pika::intrusive_ptr<resettable_operation_state_future_data<T, Allocator>> data;
+
+        friend void tag_invoke(pika::execution::experimental::set_error_t, make_future_receiver&& r,
+            std::exception_ptr ep) noexcept
         {
             // We move the receiver into a local variable from the operation
             // state which the receiver refers to. This allows us to safely
@@ -75,15 +72,15 @@ namespace pika::make_future_detail {
             r_local.data.reset();
         }
 
-        friend void tag_invoke(pika::execution::experimental::set_stopped_t,
-            make_future_receiver&&) noexcept
+        friend void tag_invoke(
+            pika::execution::experimental::set_stopped_t, make_future_receiver&&) noexcept
         {
             std::terminate();
         }
 
         template <typename U>
-        friend void tag_invoke(pika::execution::experimental::set_value_t,
-            make_future_receiver&& r, U&& u) noexcept
+        friend void tag_invoke(
+            pika::execution::experimental::set_value_t, make_future_receiver&& r, U&& u) noexcept
         {
             // We move the receiver into a local variable from the operation
             // state which the receiver refers to. This allows us to safely
@@ -92,16 +89,13 @@ namespace pika::make_future_detail {
 
             pika::detail::try_catch_exception_ptr(
                 [&]() { r_local.data->set_value(PIKA_FORWARD(U, u)); },
-                [&](std::exception_ptr ep) {
-                    r_local.data->set_exception(PIKA_MOVE(ep));
-                });
+                [&](std::exception_ptr ep) { r_local.data->set_exception(PIKA_MOVE(ep)); });
             r_local.data->reset_operation_state();
             r_local.data.reset();
         }
 
-        friend constexpr pika::execution::experimental::detail::empty_env
-        tag_invoke(pika::execution::experimental::get_env_t,
-            make_future_receiver const&) noexcept
+        friend constexpr pika::execution::experimental::empty_env tag_invoke(
+            pika::execution::experimental::get_env_t, make_future_receiver const&) noexcept
         {
             return {};
         }
@@ -110,12 +104,10 @@ namespace pika::make_future_detail {
     template <typename Allocator>
     struct make_future_receiver<void, Allocator>
     {
-        pika::intrusive_ptr<
-            resettable_operation_state_future_data<void, Allocator>>
-            data;
+        pika::intrusive_ptr<resettable_operation_state_future_data<void, Allocator>> data;
 
-        friend void tag_invoke(pika::execution::experimental::set_error_t,
-            make_future_receiver&& r, std::exception_ptr ep) noexcept
+        friend void tag_invoke(pika::execution::experimental::set_error_t, make_future_receiver&& r,
+            std::exception_ptr ep) noexcept
         {
             // We move the receiver into a local variable from the operation
             // state which the receiver refers to. This allows us to safely
@@ -127,14 +119,14 @@ namespace pika::make_future_detail {
             r_local.data.reset();
         }
 
-        friend void tag_invoke(pika::execution::experimental::set_stopped_t,
-            make_future_receiver&&) noexcept
+        friend void tag_invoke(
+            pika::execution::experimental::set_stopped_t, make_future_receiver&&) noexcept
         {
             std::terminate();
         }
 
-        friend void tag_invoke(pika::execution::experimental::set_value_t,
-            make_future_receiver&& r) noexcept
+        friend void tag_invoke(
+            pika::execution::experimental::set_value_t, make_future_receiver&& r) noexcept
         {
             // We move the receiver into a local variable from the operation
             // state which the receiver refers to. This allows us to safely
@@ -143,16 +135,13 @@ namespace pika::make_future_detail {
 
             pika::detail::try_catch_exception_ptr(
                 [&]() { r_local.data->set_value(pika::util::detail::unused); },
-                [&](std::exception_ptr ep) {
-                    r_local.data->set_exception(PIKA_MOVE(ep));
-                });
+                [&](std::exception_ptr ep) { r_local.data->set_exception(PIKA_MOVE(ep)); });
             r_local.data->reset_operation_state();
             r_local.data.reset();
         }
 
-        friend constexpr pika::execution::experimental::detail::empty_env
-        tag_invoke(pika::execution::experimental::get_env_t,
-            make_future_receiver const&) noexcept
+        friend constexpr pika::execution::experimental::empty_env tag_invoke(
+            pika::execution::experimental::get_env_t, make_future_receiver const&) noexcept
         {
             return {};
         }
@@ -164,26 +153,22 @@ namespace pika::make_future_detail {
         PIKA_NON_COPYABLE(future_data);
 
         using operation_state_type = std::decay_t<OperationState>;
-        using other_allocator = typename std::allocator_traits<
-            Allocator>::template rebind_alloc<future_data>;
+        using other_allocator =
+            typename std::allocator_traits<Allocator>::template rebind_alloc<future_data>;
         using init_no_addref =
-            typename pika::lcos::detail::future_data_allocator<T,
-                Allocator>::init_no_addref;
+            typename pika::lcos::detail::future_data_allocator<T, Allocator>::init_no_addref;
 
         // The operation state is stored in an optional so that it can be
         // reset explicitly as soon as set_* is called.
         std::optional<operation_state_type> op_state;
 
         template <typename Sender>
-        future_data(init_no_addref no_addref, other_allocator const& alloc,
-            Sender&& sender)
-          : resettable_operation_state_future_data<T, Allocator>(
-                no_addref, alloc)
+        future_data(init_no_addref no_addref, other_allocator const& alloc, Sender&& sender)
+          : resettable_operation_state_future_data<T, Allocator>(no_addref, alloc)
         {
             op_state.emplace(pika::detail::with_result_of([&]() {
                 return pika::execution::experimental::connect(
-                    PIKA_FORWARD(Sender, sender),
-                    make_future_receiver<T, Allocator>{this});
+                    PIKA_FORWARD(Sender, sender), make_future_receiver<T, Allocator>{this});
             }));
             pika::execution::experimental::start(op_state.value());
         }
@@ -200,42 +185,37 @@ namespace pika::make_future_detail {
     {
         using allocator_type = Allocator;
 
-#if defined(PIKA_HAVE_P2300_REFERENCE_IMPLEMENTATION)
+#if defined(PIKA_HAVE_STDEXEC)
         using value_types =
-            typename pika::execution::experimental::value_types_of_t<
-                std::decay_t<Sender>,
-                pika::execution::experimental::detail::empty_env,
-                pika::util::detail::pack, pika::util::detail::pack>;
+            typename pika::execution::experimental::value_types_of_t<std::decay_t<Sender>,
+                pika::execution::experimental::empty_env, pika::util::detail::pack,
+                pika::util::detail::pack>;
 #else
-        using value_types = typename pika::execution::experimental::
-            sender_traits<std::decay_t<Sender>>::template value_types<
-                pika::util::detail::pack, pika::util::detail::pack>;
+        using value_types =
+            typename pika::execution::experimental::sender_traits<std::decay_t<Sender>>::
+                template value_types<pika::util::detail::pack, pika::util::detail::pack>;
 #endif
         using result_type =
-            std::decay_t<pika::execution::experimental::detail::single_result_t<
-                value_types>>;
-        using operation_state_type = pika::util::detail::invoke_result_t<
-            pika::execution::experimental::connect_t, Sender,
-            make_future_receiver<result_type, allocator_type>>;
+            std::decay_t<pika::execution::experimental::detail::single_result_t<value_types>>;
+        using operation_state_type = std::invoke_result_t<pika::execution::experimental::connect_t,
+            Sender, make_future_receiver<result_type, allocator_type>>;
 
-        using shared_state =
-            future_data<result_type, allocator_type, operation_state_type>;
+        using shared_state = future_data<result_type, allocator_type, operation_state_type>;
         using init_no_addref = typename shared_state::init_no_addref;
-        using other_allocator = typename std::allocator_traits<
-            allocator_type>::template rebind_alloc<shared_state>;
+        using other_allocator =
+            typename std::allocator_traits<allocator_type>::template rebind_alloc<shared_state>;
         using allocator_traits = std::allocator_traits<other_allocator>;
-        using unique_ptr = std::unique_ptr<shared_state,
-            pika::detail::allocator_deleter<other_allocator>>;
+        using unique_ptr =
+            std::unique_ptr<shared_state, pika::detail::allocator_deleter<other_allocator>>;
 
         other_allocator alloc(allocator);
         unique_ptr p(allocator_traits::allocate(alloc, 1),
             pika::detail::allocator_deleter<other_allocator>{alloc});
 
-        allocator_traits::construct(alloc, p.get(), init_no_addref{}, alloc,
-            PIKA_FORWARD(Sender, sender));
+        allocator_traits::construct(
+            alloc, p.get(), init_no_addref{}, alloc, PIKA_FORWARD(Sender, sender));
 
-        return pika::traits::future_access<future<result_type>>::create(
-            p.release(), false);
+        return pika::traits::future_access<future<result_type>>::create(p.release(), false);
     }
 }    // namespace pika::make_future_detail
 
@@ -252,12 +232,10 @@ namespace pika::execution::experimental {
                 pika::detail::is_allocator_v<Allocator>
             )>
         // clang-format on
-        friend constexpr PIKA_FORCEINLINE auto
-        tag_fallback_invoke(make_future_t, Sender&& sender,
-            Allocator const& allocator = Allocator{})
+        friend constexpr PIKA_FORCEINLINE auto tag_fallback_invoke(
+            make_future_t, Sender&& sender, Allocator const& allocator = Allocator{})
         {
-            return make_future_detail::make_future(
-                PIKA_FORWARD(Sender, sender), allocator);
+            return make_future_detail::make_future(PIKA_FORWARD(Sender, sender), allocator);
         }
 
         // clang-format off
@@ -266,11 +244,10 @@ namespace pika::execution::experimental {
                 pika::detail::is_allocator_v<Allocator>
             )>
         // clang-format on
-        friend constexpr PIKA_FORCEINLINE auto tag_fallback_invoke(
-            make_future_t, Allocator const& allocator = Allocator{})
+        friend constexpr PIKA_FORCEINLINE auto
+        tag_fallback_invoke(make_future_t, Allocator const& allocator = Allocator{})
         {
-            return detail::partial_algorithm<make_future_t, Allocator>{
-                allocator};
+            return detail::partial_algorithm<make_future_t, Allocator>{allocator};
         }
     } make_future{};
 }    // namespace pika::execution::experimental
