@@ -43,8 +43,13 @@
 #include <pika/util/get_entry_as.hpp>
 #include <pika/version.hpp>
 
+#if defined(PIKA_HAVE_HIP)
+# include <hip/hip_runtime.h>
+# include <whip.hpp>
+#endif
+
 #if defined(__bgq__)
-#include <cstdlib>
+# include <cstdlib>
 #endif
 
 #include <cmath>
@@ -61,18 +66,16 @@
 #include <vector>
 
 #if !defined(PIKA_WINDOWS)
-#include <signal.h>
+# include <signal.h>
 #endif
 
-///////////////////////////////////////////////////////////////////////////////
 namespace pika {
     namespace detail {
 
         int init_helper(pika::program_options::variables_map& /*vm*/,
             util::detail::function<int(int, char**)> const& f)
         {
-            std::string cmdline(
-                pika::get_config_entry("pika.reconstructed_cmd_line", ""));
+            std::string cmdline(pika::get_config_entry("pika.reconstructed_cmd_line", ""));
 
             using namespace pika::program_options;
 #if defined(PIKA_WINDOWS)
@@ -110,19 +113,66 @@ namespace pika {
     }    // namespace detail
 
     // Print stack trace and exit.
-#if defined(PIKA_WINDOWS)
-    extern BOOL WINAPI termination_handler(DWORD ctrl_type);
-#else
-    extern void termination_handler(int signum);
-#endif
+    int init(std::function<int(pika::program_options::variables_map&)> f, int argc,
+        const char* const* argv, init_params const& params)
+    {
+        return detail::init_start_impl(PIKA_MOVE(f), argc, argv, params, true);
+    }
+
+    int init(std::function<int(int, char**)> f, int argc, const char* const* argv,
+        init_params const& params)
+    {
+        util::detail::function<int(pika::program_options::variables_map&)> main_f =
+            pika::util::detail::bind_back(pika::detail::init_helper, f);
+        return detail::init_start_impl(PIKA_MOVE(main_f), argc, argv, params, true);
+    }
+
+    int init(std::function<int()> f, int argc, const char* const* argv, init_params const& params)
+    {
+        util::detail::function<int(pika::program_options::variables_map&)> main_f =
+            pika::util::detail::bind(f);
+        return detail::init_start_impl(PIKA_MOVE(main_f), argc, argv, params, true);
+    }
+
+    int init(std::nullptr_t, int argc, const char* const* argv, init_params const& params)
+    {
+        util::detail::function<int(pika::program_options::variables_map&)> main_f;
+        return detail::init_start_impl(PIKA_MOVE(main_f), argc, argv, params, true);
+    }
+
+    bool start(std::function<int(pika::program_options::variables_map&)> f, int argc,
+        const char* const* argv, init_params const& params)
+    {
+        return 0 == detail::init_start_impl(PIKA_MOVE(f), argc, argv, params, false);
+    }
+
+    bool start(std::function<int(int, char**)> f, int argc, const char* const* argv,
+        init_params const& params)
+    {
+        util::detail::function<int(pika::program_options::variables_map&)> main_f =
+            pika::util::detail::bind_back(pika::detail::init_helper, f);
+        return 0 == detail::init_start_impl(PIKA_MOVE(main_f), argc, argv, params, false);
+    }
+
+    bool start(std::function<int()> f, int argc, const char* const* argv, init_params const& params)
+    {
+        util::detail::function<int(pika::program_options::variables_map&)> main_f =
+            pika::util::detail::bind(f);
+        return 0 == detail::init_start_impl(PIKA_MOVE(main_f), argc, argv, params, false);
+    }
+
+    bool start(std::nullptr_t, int argc, const char* const* argv, init_params const& params)
+    {
+        util::detail::function<int(pika::program_options::variables_map&)> main_f;
+        return 0 == detail::init_start_impl(PIKA_MOVE(main_f), argc, argv, params, false);
+    }
 
     int finalize(error_code& ec)
     {
         if (!is_running())
         {
             PIKA_THROWS_IF(ec, pika::error::invalid_status, "pika::finalize",
-                "the runtime system is not active (did you already "
-                "call finalize?)");
+                "the runtime system is not active (did you already call finalize?)");
             return -1;
         }
 
@@ -133,8 +183,7 @@ namespace pika {
         if (nullptr == rt)
         {
             PIKA_THROWS_IF(ec, pika::error::invalid_status, "pika::finalize",
-                "the runtime system is not active (did you already "
-                "call pika::stop?)");
+                "the runtime system is not active (did you already call pika::stop?)");
             return -1;
         }
 
@@ -156,8 +205,7 @@ namespace pika {
         if (nullptr == rt.get())
         {
             PIKA_THROWS_IF(ec, pika::error::invalid_status, "pika::stop",
-                "the runtime system is not active (did you already "
-                "call pika::stop?)");
+                "the runtime system is not active (did you already call pika::stop?)");
             return -1;
         }
 
@@ -169,7 +217,6 @@ namespace pika {
         return result;
     }
 
-    ///////////////////////////////////////////////////////////////////////////
     int suspend(error_code& ec)
     {
         if (threads::detail::get_self_ptr())
@@ -183,15 +230,13 @@ namespace pika {
         if (nullptr == rt)
         {
             PIKA_THROWS_IF(ec, pika::error::invalid_status, "pika::suspend",
-                "the runtime system is not active (did you already "
-                "call pika::stop?)");
+                "the runtime system is not active (did you already call pika::stop?)");
             return -1;
         }
 
         return rt->suspend();
     }
 
-    ///////////////////////////////////////////////////////////////////////////
     int resume(error_code& ec)
     {
         if (threads::detail::get_self_ptr())
@@ -205,22 +250,17 @@ namespace pika {
         if (nullptr == rt)
         {
             PIKA_THROWS_IF(ec, pika::error::invalid_status, "pika::resume",
-                "the runtime system is not active (did you already "
-                "call pika::stop?)");
+                "the runtime system is not active (did you already call pika::stop?)");
             return -1;
         }
 
         return rt->resume();
     }
 
-    ///////////////////////////////////////////////////////////////////////////
     namespace detail {
-
-        ///////////////////////////////////////////////////////////////////////
         void activate_global_options(detail::command_line_handling& cmdline)
         {
-#if defined(__linux) || defined(linux) || defined(__linux__) ||                \
-    defined(__FreeBSD__)
+#if defined(__linux) || defined(linux) || defined(__linux__) || defined(__FreeBSD__)
             threads::coroutines::detail::posix::use_guard_pages =
                 cmdline.rtcfg_.use_stack_guard_pages();
 #endif
@@ -236,7 +276,7 @@ namespace pika {
             }
 #endif
 #ifdef PIKA_HAVE_THREAD_MINIMAL_DEADLOCK_DETECTION
-            threads::set_minimal_deadlock_detection_enabled(
+            threads::detail::set_minimal_deadlock_detection_enabled(
                 cmdline.rtcfg_.enable_minimal_deadlock_detection());
 #endif
 #ifdef PIKA_HAVE_SPINLOCK_DEADLOCK_DETECTION
@@ -248,15 +288,14 @@ namespace pika {
                 cmdline.rtcfg_.get_spinlock_deadlock_warning_limit());
 #endif
 #if defined(PIKA_HAVE_LOGGING)
-            util::detail::init_logging_local(cmdline.rtcfg_);
+            init_logging_local(cmdline.rtcfg_);
 #else
-            util::detail::warn_if_logging_requested(cmdline.rtcfg_);
+            warn_if_logging_requested(cmdline.rtcfg_);
 #endif
         }
 
         ///////////////////////////////////////////////////////////////////////
-        void add_startup_functions(pika::runtime& rt,
-            pika::program_options::variables_map& vm,
+        void add_startup_functions(pika::runtime& rt, pika::program_options::variables_map& vm,
             startup_function_type startup, shutdown_function_type shutdown)
         {
             if (vm.count("pika:app-config"))
@@ -285,15 +324,13 @@ namespace pika {
 
         ///////////////////////////////////////////////////////////////////////
         int run(pika::runtime& rt,
-            util::detail::function<int(
-                pika::program_options::variables_map& vm)> const& f,
-            pika::program_options::variables_map& vm,
-            startup_function_type startup, shutdown_function_type shutdown)
+            util::detail::function<int(pika::program_options::variables_map& vm)> const& f,
+            pika::program_options::variables_map& vm, startup_function_type startup,
+            shutdown_function_type shutdown)
         {
             LPROGRESS_;
 
-            add_startup_functions(
-                rt, vm, PIKA_MOVE(startup), PIKA_MOVE(shutdown));
+            add_startup_functions(rt, vm, PIKA_MOVE(startup), PIKA_MOVE(shutdown));
 
             // Run this runtime instance using the given function f.
             if (!f.empty())
@@ -304,15 +341,13 @@ namespace pika {
         }
 
         int start(pika::runtime& rt,
-            util::detail::function<int(
-                pika::program_options::variables_map& vm)> const& f,
-            pika::program_options::variables_map& vm,
-            startup_function_type startup, shutdown_function_type shutdown)
+            util::detail::function<int(pika::program_options::variables_map& vm)> const& f,
+            pika::program_options::variables_map& vm, startup_function_type startup,
+            shutdown_function_type shutdown)
         {
             LPROGRESS_;
 
-            add_startup_functions(
-                rt, vm, PIKA_MOVE(startup), PIKA_MOVE(shutdown));
+            add_startup_functions(rt, vm, PIKA_MOVE(startup), PIKA_MOVE(shutdown));
 
             if (!f.empty())
             {
@@ -330,13 +365,11 @@ namespace pika {
         {
             if (blocking)
             {
-                return run(*rt, cfg.pika_main_f_, cfg.vm_, PIKA_MOVE(startup),
-                    PIKA_MOVE(shutdown));
+                return run(*rt, cfg.pika_main_f_, cfg.vm_, PIKA_MOVE(startup), PIKA_MOVE(shutdown));
             }
 
             // non-blocking version
-            start(*rt, cfg.pika_main_f_, cfg.vm_, PIKA_MOVE(startup),
-                PIKA_MOVE(shutdown));
+            start(*rt, cfg.pika_main_f_, cfg.vm_, PIKA_MOVE(startup), PIKA_MOVE(shutdown));
 
             // pointer to runtime is stored in TLS
             pika::runtime* p = rt.release();
@@ -350,24 +383,19 @@ namespace pika {
         {
             PIKA_UNUSED(pika::detail::filesystem::initial_path());
 
-            pika::detail::set_assertion_handler(
-                &pika::detail::assertion_handler);
-            pika::detail::set_custom_exception_info_handler(
-                &pika::detail::custom_exception_info);
-            pika::detail::set_pre_exception_handler(
-                &pika::detail::pre_exception_handler);
+            pika::detail::set_assertion_handler(&pika::detail::assertion_handler);
+            pika::detail::set_custom_exception_info_handler(&pika::detail::custom_exception_info);
+            pika::detail::set_pre_exception_handler(&pika::detail::pre_exception_handler);
             pika::set_thread_termination_handler(
                 [](std::exception_ptr const& e) { report_error(e); });
-            pika::lcos::detail::set_run_on_completed_error_handler(
-                [](std::exception_ptr const& e) {
-                    pika::detail::report_exception_and_terminate(e);
-                });
+            pika::lcos::detail::set_run_on_completed_error_handler([](std::exception_ptr const& e) {
+                pika::detail::report_exception_and_terminate(e);
+            });
             pika::detail::set_get_full_build_string(&pika::full_build_string);
 #if defined(PIKA_HAVE_VERIFY_LOCKS)
             pika::util::set_registered_locks_error_handler(
                 &pika::detail::registered_locks_error_handler);
-            pika::util::set_register_locks_predicate(
-                &pika::detail::register_locks_predicate);
+            pika::util::set_register_locks_predicate(&pika::detail::register_locks_predicate);
 #endif
 #if !defined(PIKA_HAVE_DISABLED_SIGNAL_EXCEPTION_HANDLERS)
             if (pika::detail::get_entry_as<bool>(
@@ -377,11 +405,9 @@ namespace pika {
             }
 
 #endif
-            pika::threads::detail::set_get_default_pool(
-                &pika::detail::get_default_pool);
+            pika::threads::detail::set_get_default_pool(&pika::detail::get_default_pool);
             pika::threads::detail::set_get_locality_id(&get_locality_id);
-            pika::parallel::execution::detail::set_get_pu_mask(
-                &pika::detail::get_pu_mask);
+            pika::parallel::execution::detail::set_get_pu_mask(&pika::detail::get_pu_mask);
             pika::parallel::execution::detail::set_get_os_thread_count(
                 []() { return pika::get_os_thread_count(); });
 
@@ -409,8 +435,8 @@ namespace pika {
             // make sure the runtime system is not active yet
             if (get_runtime_ptr() != nullptr)
             {
-                std::cerr << "pika::init: can't initialize runtime system "
-                             "more than once! Exiting...\n";
+                std::cerr
+                    << "pika::init: can't initialize runtime system more than once! Exiting...\n";
                 return -1;
             }
             return 0;
@@ -418,10 +444,8 @@ namespace pika {
 
         ///////////////////////////////////////////////////////////////////////
         int run_or_start(
-            util::detail::function<int(
-                pika::program_options::variables_map& vm)> const& f,
-            int argc, const char* const* argv, init_params const& params,
-            bool blocking)
+            util::detail::function<int(pika::program_options::variables_map& vm)> const& f,
+            int argc, const char* const* argv, init_params const& params, bool blocking)
         {
             int result = 0;
             try
@@ -432,8 +456,7 @@ namespace pika {
                 }
 
                 pika::detail::command_line_handling cmdline{
-                    pika::util::runtime_configuration(
-                        argv[0], pika::runtime_mode::local),
+                    pika::util::runtime_configuration(argv[0], pika::runtime_mode::local),
                     params.cfg, f};
 
                 // scope exception handling to resource partitioner initialization
@@ -444,23 +467,19 @@ namespace pika {
                     result = cmdline.call(params.desc_cmdline, argc, argv);
 
                     pika::detail::affinity_data affinity_data{};
-                    affinity_data.init(
-                        pika::detail::get_entry_as<std::size_t>(
-                            cmdline.rtcfg_, "pika.os_threads", 0),
-                        pika::detail::get_entry_as<std::size_t>(
-                            cmdline.rtcfg_, "pika.cores", 0),
+                    affinity_data.init(pika::detail::get_entry_as<std::size_t>(
+                                           cmdline.rtcfg_, "pika.os_threads", 0),
+                        pika::detail::get_entry_as<std::size_t>(cmdline.rtcfg_, "pika.cores", 0),
                         pika::detail::get_entry_as<std::size_t>(
                             cmdline.rtcfg_, "pika.pu_offset", 0),
-                        pika::detail::get_entry_as<std::size_t>(
-                            cmdline.rtcfg_, "pika.pu_step", 0),
+                        pika::detail::get_entry_as<std::size_t>(cmdline.rtcfg_, "pika.pu_step", 0),
                         0, cmdline.rtcfg_.get_entry("pika.affinity", ""),
                         cmdline.rtcfg_.get_entry("pika.bind", ""),
                         !pika::detail::get_entry_as<bool>(
                             cmdline.rtcfg_, "pika.ignore_process_mask", false));
 
-                    pika::resource::partitioner rp =
-                        pika::resource::detail::make_partitioner(
-                            params.rp_mode, cmdline.rtcfg_, affinity_data);
+                    pika::resource::partitioner rp = pika::resource::detail::make_partitioner(
+                        params.rp_mode, cmdline.rtcfg_, affinity_data);
 
                     activate_global_options(cmdline);
 
@@ -487,11 +506,16 @@ namespace pika {
                 }
                 catch (pika::exception const& e)
                 {
-                    std::cerr << "pika::init: pika::exception caught: "
-                              << pika::get_error_what(e) << "\n";
+                    std::cerr << "pika::init: pika::exception caught: " << pika::get_error_what(e)
+                              << "\n";
                     return -1;
                 }
 
+#if defined(PIKA_HAVE_HIP)
+                LPROGRESS_ << "run_local: initialize HIP";
+                whip::check_error(hipInit(0));
+#endif
+
                 // Initialize and start the pika runtime.
                 LPROGRESS_ << "run_local: create runtime";
 
@@ -502,13 +526,12 @@ namespace pika {
                 LPROGRESS_ << "creating local runtime";
                 rt.reset(new pika::runtime(cmdline.rtcfg_, true));
 
-                result = run_or_start(blocking, PIKA_MOVE(rt), cmdline,
-                    PIKA_MOVE(params.startup), PIKA_MOVE(params.shutdown));
+                result = run_or_start(blocking, PIKA_MOVE(rt), cmdline, PIKA_MOVE(params.startup),
+                    PIKA_MOVE(params.shutdown));
             }
             catch (pika::detail::command_line_error const& e)
             {
-                std::cerr << "pika::init: std::exception caught: " << e.what()
-                          << "\n";
+                std::cerr << "pika::init: std::exception caught: " << e.what() << "\n";
                 return -1;
             }
             return result;
