@@ -24,8 +24,8 @@
 #include <utility>
 #include <vector>
 
-std::size_t const max_threads = (std::min)(
-    std::size_t(4), std::size_t(pika::threads::detail::hardware_concurrency()));
+std::size_t const max_threads =
+    (std::min)(std::size_t(4), std::size_t(pika::threads::detail::hardware_concurrency()));
 
 int pika_main()
 {
@@ -33,42 +33,34 @@ int pika_main()
 
     PIKA_TEST_EQ(std::size_t(max_threads - 1), num_threads);
 
-    pika::threads::detail::thread_pool_base& tp =
-        pika::resource::get_thread_pool("worker");
+    pika::threads::detail::thread_pool_base& tp = pika::resource::get_thread_pool("worker");
 
     {
         // Check number of used resources
-        for (std::size_t thread_num = 0; thread_num < num_threads - 1;
-             ++thread_num)
+        for (std::size_t thread_num = 0; thread_num < num_threads - 1; ++thread_num)
         {
-            pika::threads::detail::suspend_processing_unit(tp, thread_num)
-                .get();
-            PIKA_TEST_EQ(std::size_t(num_threads - thread_num - 1),
-                tp.get_active_os_thread_count());
+            pika::threads::detail::suspend_processing_unit(tp, thread_num).get();
+            PIKA_TEST_EQ(
+                std::size_t(num_threads - thread_num - 1), tp.get_active_os_thread_count());
         }
 
-        for (std::size_t thread_num = 0; thread_num < num_threads - 1;
-             ++thread_num)
+        for (std::size_t thread_num = 0; thread_num < num_threads - 1; ++thread_num)
         {
             pika::threads::detail::resume_processing_unit(tp, thread_num).get();
-            PIKA_TEST_EQ(
-                std::size_t(thread_num + 2), tp.get_active_os_thread_count());
+            PIKA_TEST_EQ(std::size_t(thread_num + 2), tp.get_active_os_thread_count());
         }
     }
 
     {
         // Check suspending and resuming the same thread without waiting for
         // each to finish.
-        for (std::size_t thread_num = 0;
-             thread_num < pika::resource::get_num_threads("worker");
+        for (std::size_t thread_num = 0; thread_num < pika::resource::get_num_threads("worker");
              ++thread_num)
         {
             std::vector<pika::future<void>> fs;
 
-            fs.push_back(
-                pika::threads::detail::suspend_processing_unit(tp, thread_num));
-            fs.push_back(
-                pika::threads::detail::resume_processing_unit(tp, thread_num));
+            fs.push_back(pika::threads::detail::suspend_processing_unit(tp, thread_num));
+            fs.push_back(pika::threads::detail::resume_processing_unit(tp, thread_num));
 
             pika::wait_all(fs);
 
@@ -82,8 +74,7 @@ int pika_main()
             // as no thread is available to steal from the current thread.
             for (std::size_t i = 0; i < max_threads - 1; ++i)
             {
-                fs.push_back(pika::threads::detail::suspend_processing_unit(
-                    tp, thread_num));
+                fs.push_back(pika::threads::detail::suspend_processing_unit(tp, thread_num));
             }
 
             pika::wait_all(fs);
@@ -94,8 +85,7 @@ int pika_main()
             // as no thread is available to steal from the current thread.
             for (std::size_t i = 0; i < max_threads - 1; ++i)
             {
-                fs.push_back(pika::threads::detail::resume_processing_unit(
-                    tp, thread_num));
+                fs.push_back(pika::threads::detail::resume_processing_unit(tp, thread_num));
             }
 
             pika::wait_all(fs);
@@ -110,8 +100,7 @@ int pika_main()
         pika::chrono::detail::high_resolution_timer t;
         while (t.elapsed() < 2)
         {
-            for (std::size_t i = 0;
-                 i < pika::resource::get_num_threads("worker") * 10; ++i)
+            for (std::size_t i = 0; i < pika::resource::get_num_threads("worker") * 10; ++i)
             {
                 fs.push_back(pika::async([]() {}));
             }
@@ -120,9 +109,7 @@ int pika_main()
             {
                 if (thread_num < pika::resource::get_num_threads("worker"))
                 {
-                    pika::threads::detail::suspend_processing_unit(
-                        tp, thread_num)
-                        .get();
+                    pika::threads::detail::suspend_processing_unit(tp, thread_num).get();
                 }
 
                 ++thread_num;
@@ -135,8 +122,7 @@ int pika_main()
             }
             else
             {
-                pika::threads::detail::resume_processing_unit(tp, thread_num)
-                    .get();
+                pika::threads::detail::resume_processing_unit(tp, thread_num).get();
 
                 if (thread_num > 0)
                 {
@@ -152,28 +138,24 @@ int pika_main()
         pika::when_all(std::move(fs)).get();
 
         // Don't exit with suspended pus
-        for (std::size_t thread_num_resume = 0; thread_num_resume < thread_num;
-             ++thread_num_resume)
+        for (std::size_t thread_num_resume = 0; thread_num_resume < thread_num; ++thread_num_resume)
         {
-            pika::threads::detail::resume_processing_unit(tp, thread_num_resume)
-                .get();
+            pika::threads::detail::resume_processing_unit(tp, thread_num_resume).get();
         }
     }
 
     return pika::finalize();
 }
 
-void test_scheduler(
-    int argc, char* argv[], pika::resource::scheduling_policy scheduler)
+void test_scheduler(int argc, char* argv[], pika::resource::scheduling_policy scheduler)
 {
     pika::init_params init_args;
 
     using ::pika::threads::scheduler_mode;
     init_args.cfg = {"pika.os_threads=" + std::to_string(max_threads)};
-    init_args.rp_callback = [scheduler](auto& rp,
-                                pika::program_options::variables_map const&) {
-        rp.create_thread_pool("worker", scheduler,
-            scheduler_mode::default_mode | scheduler_mode::enable_elasticity);
+    init_args.rp_callback = [scheduler](auto& rp, pika::program_options::variables_map const&) {
+        rp.create_thread_pool(
+            "worker", scheduler, scheduler_mode::default_mode | scheduler_mode::enable_elasticity);
 
         std::size_t const worker_pool_threads = max_threads - 1;
         std::size_t worker_pool_threads_added = 0;
