@@ -9,7 +9,6 @@
 #include <pika/config.hpp>
 #include <pika/assert.hpp>
 #include <pika/functional/detail/invoke.hpp>
-#include <pika/functional/invoke_result.hpp>
 #include <pika/synchronization/spinlock.hpp>
 #include <pika/threading_base/thread_helpers.hpp>
 
@@ -29,8 +28,7 @@ namespace pika::threads {
     namespace detail {
         // This is the overload for running functions which return a value.
         template <typename F, typename... Ts>
-        typename util::detail::invoke_result<F, Ts...>::type
-        run_as_pika_thread(std::false_type, F const& f, Ts&&... ts)
+        std::invoke_result_t<F, Ts...> run_as_pika_thread(std::false_type, F const& f, Ts&&... ts)
         {
             // NOTE: The condition variable needs be able to live past the scope
             // of this function. The mutex and boolean are guaranteed to live
@@ -39,8 +37,7 @@ namespace pika::threads {
             auto cond = std::make_shared<std::condition_variable_any>();
             bool stopping = false;
 
-            using result_type =
-                typename util::detail::invoke_result<F, Ts...>::type;
+            using result_type = std::invoke_result_t<F, Ts...>;
 
             // Using the optional for storing the returned result value
             // allows to support non-default-constructible and move-only
@@ -50,29 +47,27 @@ namespace pika::threads {
 
             // Create the pika thread
             pika::threads::detail::thread_init_data data(
-                pika::threads::detail::make_thread_function_nullary(
-                    [&, cond]() {
-                        try
-                        {
-                            // Execute the given function, forward all parameters,
-                            // store result.
-                            result.emplace(
-                                PIKA_INVOKE(f, PIKA_FORWARD(Ts, ts)...));
-                        }
-                        catch (...)
-                        {
-                            // make sure exceptions do not escape the pika thread
-                            // scheduler
-                            exception = std::current_exception();
-                        }
+                pika::threads::detail::make_thread_function_nullary([&, cond]() {
+                    try
+                    {
+                        // Execute the given function, forward all parameters,
+                        // store result.
+                        result.emplace(PIKA_INVOKE(f, PIKA_FORWARD(Ts, ts)...));
+                    }
+                    catch (...)
+                    {
+                        // make sure exceptions do not escape the pika thread
+                        // scheduler
+                        exception = std::current_exception();
+                    }
 
-                        // Now signal to the waiting thread that we're done.
-                        {
-                            std::lock_guard<pika::spinlock> lk(mtx);
-                            stopping = true;
-                        }
-                        cond->notify_all();
-                    }),
+                    // Now signal to the waiting thread that we're done.
+                    {
+                        std::lock_guard<pika::spinlock> lk(mtx);
+                        stopping = true;
+                    }
+                    cond->notify_all();
+                }),
                 "run_as_pika_thread (non-void)");
             pika::threads::detail::register_work(data);
 
@@ -102,27 +97,26 @@ namespace pika::threads {
 
             // Create an pika thread
             pika::threads::detail::thread_init_data data(
-                pika::threads::detail::make_thread_function_nullary(
-                    [&, cond]() {
-                        try
-                        {
-                            // Execute the given function, forward all parameters.
-                            PIKA_INVOKE(f, PIKA_FORWARD(Ts, ts)...);
-                        }
-                        catch (...)
-                        {
-                            // make sure exceptions do not escape the pika thread
-                            // scheduler
-                            exception = std::current_exception();
-                        }
+                pika::threads::detail::make_thread_function_nullary([&, cond]() {
+                    try
+                    {
+                        // Execute the given function, forward all parameters.
+                        PIKA_INVOKE(f, PIKA_FORWARD(Ts, ts)...);
+                    }
+                    catch (...)
+                    {
+                        // make sure exceptions do not escape the pika thread
+                        // scheduler
+                        exception = std::current_exception();
+                    }
 
-                        // Now signal to the waiting thread that we're done.
-                        {
-                            std::lock_guard<pika::spinlock> lk(mtx);
-                            stopping = true;
-                        }
-                        cond->notify_all();
-                    }),
+                    // Now signal to the waiting thread that we're done.
+                    {
+                        std::lock_guard<pika::spinlock> lk(mtx);
+                        stopping = true;
+                    }
+                    cond->notify_all();
+                }),
                 "run_as_pika_thread (void)");
             pika::threads::detail::register_work(data);
 
@@ -138,16 +132,13 @@ namespace pika::threads {
 
     ///////////////////////////////////////////////////////////////////////////
     template <typename F, typename... Ts>
-    typename util::detail::invoke_result<F, Ts...>::type
-    run_as_pika_thread(F const& f, Ts&&... vs)
+    std::invoke_result_t<F, Ts...> run_as_pika_thread(F const& f, Ts&&... vs)
     {
         // This shouldn't be used on a pika-thread
         PIKA_ASSERT(pika::threads::detail::get_self_ptr() == nullptr);
 
-        using result_is_void = typename std::is_void<
-            typename util::detail::invoke_result<F, Ts...>::type>::type;
+        using result_is_void = typename std::is_void<std::invoke_result_t<F, Ts...>>::type;
 
-        return detail::run_as_pika_thread(
-            result_is_void(), f, PIKA_FORWARD(Ts, vs)...);
+        return detail::run_as_pika_thread(result_is_void(), f, PIKA_FORWARD(Ts, vs)...);
     }
 }    // namespace pika::threads
