@@ -23,11 +23,11 @@
 #include "shared_mutex_locking_thread.hpp"
 #include "thread_group.hpp"
 
-#define CHECK_LOCKED_VALUE_EQUAL(mutex_name, value, expected_value)            \
-    {                                                                          \
-        std::unique_lock<pika::mutex> lock(mutex_name);                        \
-        PIKA_TEST_EQ(value, expected_value);                                   \
-    }
+#define CHECK_LOCKED_VALUE_EQUAL(mutex_name, value, expected_value)                                \
+ {                                                                                                 \
+  std::unique_lock<pika::mutex> lock(mutex_name);                                                  \
+  PIKA_TEST_EQ(value, expected_value);                                                             \
+ }
 
 void test_multiple_readers()
 {
@@ -51,11 +51,9 @@ void test_multiple_readers()
     {
         for (unsigned i = 0; i != number_of_threads; ++i)
         {
-            pool.create_thread(
-                test::locking_thread<std::shared_lock<shared_mutex_type>>(
-                    rw_mutex, unblocked_count, unblocked_count_mutex,
-                    unblocked_condition, finish_mutex,
-                    simultaneous_running_count, max_simultaneous_running));
+            pool.create_thread(test::locking_thread<std::shared_lock<shared_mutex_type>>(rw_mutex,
+                unblocked_count, unblocked_count_mutex, unblocked_condition, finish_mutex,
+                simultaneous_running_count, max_simultaneous_running));
         }
 
         {
@@ -67,8 +65,7 @@ void test_multiple_readers()
             }
         }
 
-        CHECK_LOCKED_VALUE_EQUAL(
-            unblocked_count_mutex, unblocked_count, number_of_threads);
+        CHECK_LOCKED_VALUE_EQUAL(unblocked_count_mutex, unblocked_count, number_of_threads);
 
         finish_lock.unlock();
         pool.join_all();
@@ -80,8 +77,7 @@ void test_multiple_readers()
         PIKA_TEST(false);
     }
 
-    CHECK_LOCKED_VALUE_EQUAL(
-        unblocked_count_mutex, max_simultaneous_running, number_of_threads);
+    CHECK_LOCKED_VALUE_EQUAL(unblocked_count_mutex, max_simultaneous_running, number_of_threads);
 }
 
 void test_only_one_writer_permitted()
@@ -106,11 +102,9 @@ void test_only_one_writer_permitted()
     {
         for (unsigned i = 0; i != number_of_threads; ++i)
         {
-            pool.create_thread(
-                test::locking_thread<std::unique_lock<shared_mutex_type>>(
-                    rw_mutex, unblocked_count, unblocked_count_mutex,
-                    unblocked_condition, finish_mutex,
-                    simultaneous_running_count, max_simultaneous_running));
+            pool.create_thread(test::locking_thread<std::unique_lock<shared_mutex_type>>(rw_mutex,
+                unblocked_count, unblocked_count_mutex, unblocked_condition, finish_mutex,
+                simultaneous_running_count, max_simultaneous_running));
         }
 
         pika::this_thread::yield();
@@ -127,10 +121,8 @@ void test_only_one_writer_permitted()
         PIKA_TEST(false);
     }
 
-    CHECK_LOCKED_VALUE_EQUAL(
-        unblocked_count_mutex, unblocked_count, number_of_threads);
-    CHECK_LOCKED_VALUE_EQUAL(
-        unblocked_count_mutex, max_simultaneous_running, 1u);
+    CHECK_LOCKED_VALUE_EQUAL(unblocked_count_mutex, unblocked_count, number_of_threads);
+    CHECK_LOCKED_VALUE_EQUAL(unblocked_count_mutex, max_simultaneous_running, 1u);
 }
 
 void test_reader_blocks_writer()
@@ -151,11 +143,9 @@ void test_reader_blocks_writer()
 
     try
     {
-        pool.create_thread(
-            test::locking_thread<std::shared_lock<shared_mutex_type>>(rw_mutex,
-                unblocked_count, unblocked_count_mutex, unblocked_condition,
-                finish_mutex, simultaneous_running_count,
-                max_simultaneous_running));
+        pool.create_thread(test::locking_thread<std::shared_lock<shared_mutex_type>>(rw_mutex,
+            unblocked_count, unblocked_count_mutex, unblocked_condition, finish_mutex,
+            simultaneous_running_count, max_simultaneous_running));
 
         {
             std::unique_lock<mutex_type> lk(unblocked_count_mutex);
@@ -168,11 +158,9 @@ void test_reader_blocks_writer()
 
         CHECK_LOCKED_VALUE_EQUAL(unblocked_count_mutex, unblocked_count, 1u);
 
-        pool.create_thread(
-            test::locking_thread<std::unique_lock<shared_mutex_type>>(rw_mutex,
-                unblocked_count, unblocked_count_mutex, unblocked_condition,
-                finish_mutex, simultaneous_running_count,
-                max_simultaneous_running));
+        pool.create_thread(test::locking_thread<std::unique_lock<shared_mutex_type>>(rw_mutex,
+            unblocked_count, unblocked_count_mutex, unblocked_condition, finish_mutex,
+            simultaneous_running_count, max_simultaneous_running));
 
         pika::this_thread::yield();
 
@@ -189,8 +177,7 @@ void test_reader_blocks_writer()
     }
 
     CHECK_LOCKED_VALUE_EQUAL(unblocked_count_mutex, unblocked_count, 2u);
-    CHECK_LOCKED_VALUE_EQUAL(
-        unblocked_count_mutex, max_simultaneous_running, 1u);
+    CHECK_LOCKED_VALUE_EQUAL(unblocked_count_mutex, max_simultaneous_running, 1u);
 }
 
 void test_unlocking_writer_unblocks_all_readers()
@@ -216,11 +203,9 @@ void test_unlocking_writer_unblocks_all_readers()
     {
         for (unsigned i = 0; i != reader_count; ++i)
         {
-            pool.create_thread(
-                test::locking_thread<std::shared_lock<shared_mutex_type>>(
-                    rw_mutex, unblocked_count, unblocked_count_mutex,
-                    unblocked_condition, finish_mutex,
-                    simultaneous_running_count, max_simultaneous_running));
+            pool.create_thread(test::locking_thread<std::shared_lock<shared_mutex_type>>(rw_mutex,
+                unblocked_count, unblocked_count_mutex, unblocked_condition, finish_mutex,
+                simultaneous_running_count, max_simultaneous_running));
         }
 
         pika::this_thread::yield();
@@ -238,8 +223,7 @@ void test_unlocking_writer_unblocks_all_readers()
             }
         }
 
-        CHECK_LOCKED_VALUE_EQUAL(
-            unblocked_count_mutex, unblocked_count, reader_count);
+        CHECK_LOCKED_VALUE_EQUAL(unblocked_count_mutex, unblocked_count, reader_count);
 
         finish_lock.unlock();
         pool.join_all();
@@ -251,8 +235,7 @@ void test_unlocking_writer_unblocks_all_readers()
         PIKA_TEST(false);
     }
 
-    CHECK_LOCKED_VALUE_EQUAL(
-        unblocked_count_mutex, max_simultaneous_running, reader_count);
+    CHECK_LOCKED_VALUE_EQUAL(unblocked_count_mutex, max_simultaneous_running, reader_count);
 }
 
 void test_unlocking_last_reader_only_unblocks_one_writer()
@@ -282,11 +265,9 @@ void test_unlocking_last_reader_only_unblocks_one_writer()
     {
         for (unsigned i = 0; i != reader_count; ++i)
         {
-            pool.create_thread(
-                test::locking_thread<std::shared_lock<shared_mutex_type>>(
-                    rw_mutex, unblocked_count, unblocked_count_mutex,
-                    unblocked_condition, finish_reading_mutex,
-                    simultaneous_running_readers, max_simultaneous_readers));
+            pool.create_thread(test::locking_thread<std::shared_lock<shared_mutex_type>>(rw_mutex,
+                unblocked_count, unblocked_count_mutex, unblocked_condition, finish_reading_mutex,
+                simultaneous_running_readers, max_simultaneous_readers));
         }
 
         std::this_thread::sleep_for(std::chrono::seconds(1));
@@ -294,11 +275,9 @@ void test_unlocking_last_reader_only_unblocks_one_writer()
 
         for (unsigned i = 0; i != writer_count; ++i)
         {
-            pool.create_thread(
-                test::locking_thread<std::unique_lock<shared_mutex_type>>(
-                    rw_mutex, unblocked_count, unblocked_count_mutex,
-                    unblocked_condition, finish_writing_mutex,
-                    simultaneous_running_writers, max_simultaneous_writers));
+            pool.create_thread(test::locking_thread<std::unique_lock<shared_mutex_type>>(rw_mutex,
+                unblocked_count, unblocked_count_mutex, unblocked_condition, finish_writing_mutex,
+                simultaneous_running_writers, max_simultaneous_writers));
         }
 
         {
@@ -313,8 +292,7 @@ void test_unlocking_last_reader_only_unblocks_one_writer()
         std::this_thread::sleep_for(std::chrono::seconds(1));
         pika::this_thread::yield();
 
-        CHECK_LOCKED_VALUE_EQUAL(
-            unblocked_count_mutex, unblocked_count, reader_count);
+        CHECK_LOCKED_VALUE_EQUAL(unblocked_count_mutex, unblocked_count, reader_count);
 
         finish_reading_lock.unlock();
 
@@ -327,8 +305,7 @@ void test_unlocking_last_reader_only_unblocks_one_writer()
             }
         }
 
-        CHECK_LOCKED_VALUE_EQUAL(
-            unblocked_count_mutex, unblocked_count, reader_count + 1);
+        CHECK_LOCKED_VALUE_EQUAL(unblocked_count_mutex, unblocked_count, reader_count + 1);
 
         finish_writing_lock.unlock();
         pool.join_all();
@@ -340,12 +317,9 @@ void test_unlocking_last_reader_only_unblocks_one_writer()
         PIKA_TEST(false);
     }
 
-    CHECK_LOCKED_VALUE_EQUAL(
-        unblocked_count_mutex, unblocked_count, reader_count + writer_count);
-    CHECK_LOCKED_VALUE_EQUAL(
-        unblocked_count_mutex, max_simultaneous_readers, reader_count);
-    CHECK_LOCKED_VALUE_EQUAL(
-        unblocked_count_mutex, max_simultaneous_writers, 1u);
+    CHECK_LOCKED_VALUE_EQUAL(unblocked_count_mutex, unblocked_count, reader_count + writer_count);
+    CHECK_LOCKED_VALUE_EQUAL(unblocked_count_mutex, max_simultaneous_readers, reader_count);
+    CHECK_LOCKED_VALUE_EQUAL(unblocked_count_mutex, max_simultaneous_writers, 1u);
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -368,8 +342,8 @@ int main(int argc, char* argv[])
     // Initialize and run pika
     pika::init_params init_args;
     init_args.cfg = cfg;
-    PIKA_TEST_EQ_MSG(pika::init(pika_main, argc, argv, init_args), 0,
-        "pika main exited with non-zero status");
+    PIKA_TEST_EQ_MSG(
+        pika::init(pika_main, argc, argv, init_args), 0, "pika main exited with non-zero status");
 
     return 0;
 }
