@@ -13,12 +13,5 @@
 #include <cstdint>
 
 namespace pika::threads::detail {
-#if defined(PIKA_HAVE_BACKGROUND_THREAD_COUNTERS) &&                           \
-    defined(PIKA_HAVE_THREAD_IDLE_RATES)
-    using network_background_callback_type =
-        util::detail::function<bool(std::size_t, std::int64_t&, std::int64_t&)>;
-#else
-    using network_background_callback_type =
-        util::detail::function<bool(std::size_t)>;
-#endif
+    using network_background_callback_type = util::detail::function<bool(std::size_t)>;
 }    // namespace pika::threads::detail
