@@ -12,8 +12,7 @@
 
 namespace pika::detail {
     // helper function for counter evaluation
-    inline std::uint64_t get_and_reset_value(
-        std::uint64_t& value, bool reset) noexcept
+    inline std::uint64_t get_and_reset_value(std::uint64_t& value, bool reset) noexcept
     {
         std::uint64_t result = value;
         if (reset)
@@ -21,8 +20,7 @@ namespace pika::detail {
         return result;
     }
 
-    inline std::int64_t get_and_reset_value(
-        std::int64_t& value, bool reset) noexcept
+    inline std::int64_t get_and_reset_value(std::int64_t& value, bool reset) noexcept
     {
         std::int64_t result = value;
         if (reset)
